<?php
/**
 * Plugin Name: Replicat AI Support
 * Plugin URI: https://replicat.co
 * Description: Embed your Replicat AI Support widget on any WordPress site.
 * Version: 1.0.0
 * Author: Replicat
 * Author URI: https://replicat.co/
 * License: GPL2
 */

add_action('admin_menu', 'add_replicat_options_page');

// Add the options page to the admin menu
function add_replicat_options_page() {
    add_options_page('Replicat Plugin Settings', 'Replicat Options', 'administrator', 'replicat_id', 'replicat_options_page');
    add_action('admin_init', 'register_replicat_options');
}

// Register the options settings
function register_replicat_options() {
    register_setting(
        'replicat_options', 
        'replicat_widget_id',
        array(
            'type' => 'string',
            'sanitize_callback' => 'sanitize_text_field',
            'default' => ''
        )
    );
}

// Define the content of the options page
function replicat_options_page() {
    ?>
    <div class="wrap">
        <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
        <div id="form-container">
            <form method="post" action="options.php">
                <?php settings_fields('replicat_options'); ?>
                <?php do_settings_sections('replicat_options'); ?>

                <div class="logo-container">
                    <a href="https://replicat.co/" target="_blank">
                        <img alt="Replicat" loading="lazy" width="64" style="color:transparent"
                            src="https://replicat.co/logo.png">
                    </a>
                </div>

                <div class="form-group">
                    <label for="replicat_widget_id" class="text-secondary">Widget ID</label>
                    <input type="text" class="form-control" placeholder="Widget ID" name="replicat_widget_id" 
                        value="<?php echo esc_attr(get_option('replicat_widget_id')); ?>" required />
                </div>
                <label class="note-label">*Note: Copy your Widget ID from your <a href="https://replicat.co/app/dashboard"
                        target="_blank">Replicat dashboard</a>  settings. Select the chatbot you want to embed then go to "Chatbot" on the left sidebar, then choose "Integrations" and copy the API Key.</label>
                <div class="submit-btn-container">
                    <?php submit_button(); ?>
                </div>
            </form>
        </div>
    </div>
    <?php
}

// Embed the script on the site
function replicat_embed_widget() {
    $handle = 'replicat-widget';
    $widget_id = get_option('replicat_widget_id');
    
    wp_register_script($handle, '', [], '', true);
    wp_enqueue_script($handle);

    if (empty($widget_id)) {
        wp_add_inline_script($handle, 
            'console.log("Replicat Widget ID is not configured. Please enter your Widget ID in the WordPress admin settings.");'
        );
        return;
    }

    // Add CSS fixes
    $custom_css = "
        /* Reset styles for widget elements */
        [id^='chatbase-message-bubbles'],
        [id^='chatbase-message-bubbles'] * {
            all: revert;
            box-sizing: border-box !important;
        }

        /* Fix icon centering and visibility */
        body > div[style*='position: fixed'][style*='bottom: 20px'] {
            display: flex !important;
            align-items: center !important;
            justify-content: center !important;
            box-shadow: none !important;
            border: none !important;
            padding: 0 !important;
        }

        /* Fix icon states */
        body > div[style*='position: fixed'][style*='bottom: 20px'] > div:first-child {
            display: block !important;
        }

        body > div[style*='position: fixed'][style*='bottom: 20px'] > div:last-child {
            display: none !important;
        }

        /* Show close icon when widget is open */
        body > div[style*='position: fixed'][style*='bottom: 20px'][style*='transform: rotate(180deg)'] > div:first-child {
            display: none !important;
        }

        body > div[style*='position: fixed'][style*='bottom: 20px'][style*='transform: rotate(180deg)'] > div:last-child {
            display: block !important;
        }

        /* Fix iframe borders */
        body > iframe[style*='position: fixed'] {
            border: none !important;
            background: none !important;
            outline: none !important;
        }

        /* Message bubbles styling fixes */
        #chatbase-message-bubbles {
            font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, sans-serif !important;
        }
    ";
    
    wp_add_inline_style('replicat-widget-styles', $custom_css);
    
    $custom_script = '(function() {
        if (typeof window.initializeAISupportWidget === "undefined") {
            const script = document.createElement("script");
            script.src = "https://replicat.co/widget-loader.js";
            script.async = true;
            script.onload = function() {
                window.initializeAISupportWidget({
                    widgetId: "' . esc_js($widget_id) . '"
                });
            };
            document.body.appendChild(script);
        }
    })();';
    
    wp_add_inline_script($handle, $custom_script);
}

// Register styles
function replicat_register_styles() {
    wp_register_style('replicat-widget-styles', false);
    wp_enqueue_style('replicat-widget-styles');
}

add_action('wp_enqueue_scripts', 'replicat_register_styles');
add_action('wp_enqueue_scripts', 'replicat_embed_widget');
?>